@@ -1,12 +1,11 @@
 """Contains connection representation."""
-
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
 import asyncio
 from collections.abc import MutableMapping
 import logging
-from typing import Any, Final, Optional, Tuple
+from typing import Any, Final, Tuple
 
 from serial import SerialException
 import serial_asyncio
@@ -26,7 +25,7 @@ class Connection(ABC):
     must me inherited from this class."""
 
     _kwargs: MutableMapping[str, Any]
-    _protocol: Optional[Protocol] = None
+    _protocol: Protocol
     _closing: bool = False
     _reconnect_on_failure: bool = True
 
@@ -85,7 +84,7 @@ class Connection(ABC):
                 return
             except ConnectionFailedError:
                 _LOGGER.error(
-                    "ConnectionError: connection failed, reconnecting in %i seconds...",
+                    "ConnectionError: connection to device failed, retrying in %.1f seconds",
                     RECONNECT_TIMEOUT,
                 )
                 await asyncio.sleep(RECONNECT_TIMEOUT)
@@ -106,7 +105,7 @@ class Connection(ABC):
             await self.protocol.shutdown()
 
     @property
-    def protocol(self) -> Optional[Protocol]:
+    def protocol(self) -> Protocol:
         """Return protocol object."""
         return self._protocol
 
