@@ -3,22 +3,22 @@ from __future__ import annotations
 
 from abc import ABC
 import asyncio
-from collections.abc import MutableMapping, Sequence
+from collections.abc import Sequence
 import time
 from typing import Dict, List, Type
 
 from pyplumio.const import (
+    ATTR_BOILER_PARAMETERS,
+    ATTR_BOILER_SENSORS,
+    ATTR_FRAME_VERSIONS,
+    ATTR_FUEL_BURNED,
+    ATTR_FUEL_CONSUMPTION,
+    ATTR_MIXER_PARAMETERS,
+    ATTR_MIXER_SENSORS,
+    ATTR_MODE,
+    ATTR_REGDATA,
+    ATTR_SCHEMA,
     BROADCAST_ADDRESS,
-    DATA_BOILER_PARAMETERS,
-    DATA_BOILER_SENSORS,
-    DATA_FRAME_VERSIONS,
-    DATA_FUEL_BURNED,
-    DATA_FUEL_CONSUMPTION,
-    DATA_MIXER_PARAMETERS,
-    DATA_MIXER_SENSORS,
-    DATA_MODE,
-    DATA_REGDATA,
-    DATA_SCHEMA,
     ECOMAX_ADDRESS,
     ECOSTER_ADDRESS,
 )
@@ -42,15 +42,14 @@ from pyplumio.helpers.parameter import (
 from pyplumio.helpers.task_manager import TaskManager
 from pyplumio.helpers.timeout import timeout
 from pyplumio.helpers.typing import (
-    Numeric,
-    Parameters,
-    ParameterTuple,
-    Records,
-    ValueCallback,
+    DeviceDataType,
+    NumericType,
+    SensorCallbackType,
+    VersionsInfoType,
 )
 from pyplumio.structures.boiler_parameters import PARAMETER_BOILER_CONTROL
 
-devices: Dict[int, str] = {
+DEVICE_TYPES: Dict[int, str] = {
     ECOMAX_ADDRESS: "EcoMAX",
     ECOSTER_ADDRESS: "EcoSTER",
 }
@@ -61,8 +60,8 @@ VALUE_TIMEOUT: int = 10
 
 def get_device_handler(address: int) -> str:
     """Return module and class for device address."""
-    if address in devices:
-        return "devices." + devices[address]
+    if address in DEVICE_TYPES:
+        return "devices." + DEVICE_TYPES[address]
 
     raise UnknownDeviceError(f"Unknown device: {address}")
 
@@ -70,7 +69,7 @@ def get_device_handler(address: int) -> str:
 class FrameVersions:
     """Represents frame versions storage."""
 
-    versions: Dict[int, int]
+    versions: VersionsInfoType
     _queue: asyncio.Queue
     _device: Device
 
@@ -80,7 +79,7 @@ class FrameVersions:
         self._queue = queue
         self._device = device
 
-    def update(self, frame_versions: MutableMapping[int, int]) -> None:
+    def update(self, frame_versions: VersionsInfoType) -> None:
         """Check versions and fetch outdated frames."""
         for frame_type, version in frame_versions.items():
             if frame_type not in self.versions or self.versions[frame_type] != version:
@@ -103,7 +102,7 @@ class FrameVersions:
 class AsyncDevice(ABC, TaskManager):
     """Represents a device with awaitable properties."""
 
-    _callbacks: Dict[str, List[ValueCallback]]
+    _callbacks: Dict[str, List[SensorCallbackType]]
 
     def __init__(self):
         """Initializes Async Device object."""
@@ -122,7 +121,7 @@ class AsyncDevice(ABC, TaskManager):
         return int(value) if isinstance(value, Parameter) else value
 
     @timeout(VALUE_TIMEOUT)
-    async def set_value(self, name: str, value: Numeric) -> None:
+    async def set_value(self, name: str, value: NumericType) -> None:
         """Set parameter value. Name should point
         to a valid parameter object."""
         if not hasattr(self, name):
@@ -166,14 +165,14 @@ class AsyncDevice(ABC, TaskManager):
         self.cancel_tasks()
         await self.wait_until_done()
 
-    def register_callback(self, name: str, callback: ValueCallback) -> None:
+    def register_callback(self, name: str, callback: SensorCallbackType) -> None:
         """Register callback for a value change."""
         if name not in self._callbacks:
             self._callbacks[name] = []
 
         self._callbacks[name].append(callback)
 
-    def remove_callback(self, name: str, callback: ValueCallback) -> None:
+    def remove_callback(self, name: str, callback: SensorCallbackType) -> None:
         """Remove value change callback."""
         if name in self._callbacks and callback in self._callbacks[name]:
             self._callbacks[name].remove(callback)
@@ -201,7 +200,7 @@ class Device(AsyncDevice):
         self._queue = queue
         versions = FrameVersions(queue, device=self)
         versions.update({x.frame_type: 0 for x in self.required_frames})
-        self.register_callback(DATA_FRAME_VERSIONS, on_change(versions.async_update))
+        self.register_callback(ATTR_FRAME_VERSIONS, on_change(versions.async_update))
 
     def handle_frame(self, frame: Frame) -> None:
         """Handle received frame."""
@@ -239,13 +238,13 @@ class EcoMAX(Device):
         super().__init__(queue)
         self._mixers: Dict[int, Mixer] = {}
         self._fuel_burned_timestamp = time.time()
-        self.register_callback(DATA_BOILER_SENSORS, self._add_boiler_sensors)
-        self.register_callback(DATA_MODE, on_change(self._add_boiler_control_parameter))
-        self.register_callback(DATA_FUEL_CONSUMPTION, self._add_burned_fuel_counter)
-        self.register_callback(DATA_BOILER_PARAMETERS, self._add_boiler_parameters)
-        self.register_callback(DATA_REGDATA, self._parse_regulator_data)
-        self.register_callback(DATA_MIXER_SENSORS, self._set_mixer_sensors)
-        self.register_callback(DATA_MIXER_PARAMETERS, self._set_mixer_parameters)
+        self.register_callback(ATTR_BOILER_SENSORS, self._add_boiler_sensors)
+        self.register_callback(ATTR_MODE, on_change(self._add_boiler_control_parameter))
+        self.register_callback(ATTR_FUEL_CONSUMPTION, self._add_burned_fuel_counter)
+        self.register_callback(ATTR_BOILER_PARAMETERS, self._add_boiler_parameters)
+        self.register_callback(ATTR_REGDATA, self._decode_regulator_data)
+        self.register_callback(ATTR_MIXER_SENSORS, self._set_mixer_sensors)
+        self.register_callback(ATTR_MIXER_PARAMETERS, self._set_mixer_parameters)
 
     def _get_mixer(self, mixer_number: int) -> Mixer:
         """Get or create a new mixer object and add it to the device."""
@@ -257,14 +256,14 @@ class EcoMAX(Device):
         self.mixers[mixer_number] = mixer
         return mixer
 
-    async def _add_boiler_sensors(self, sensors: Records):
+    async def _add_boiler_sensors(self, sensors: DeviceDataType):
         """Add boiler sensors values to the device object."""
         for name, value in sensors.items():
             await self.async_set_attribute(name, value)
 
     async def _add_boiler_parameters(
-        self, parameters: Parameters
-    ) -> Dict[str, Parameter]:
+        self, parameters: DeviceDataType
+    ) -> DeviceDataType:
         """Add Parameter objects to the device object."""
         parameter_objects: Dict[str, Parameter] = {}
         for name, value in parameters.items():
@@ -284,18 +283,14 @@ class EcoMAX(Device):
 
         return parameter_objects
 
-    async def _set_mixer_sensors(
-        self, sensors: Sequence[MutableMapping[str, Records]]
-    ) -> None:
+    async def _set_mixer_sensors(self, sensors: Sequence[DeviceDataType]) -> None:
         """Set sensor values for the mixer."""
         for mixer_number, mixer_data in enumerate(sensors):
             mixer = self._get_mixer(mixer_number)
             for name, value in mixer_data.items():
                 await mixer.async_set_attribute(name, value)
 
-    async def _set_mixer_parameters(
-        self, parameters: Sequence[MutableMapping[str, ParameterTuple]]
-    ) -> None:
+    async def _set_mixer_parameters(self, parameters: Sequence[DeviceDataType]) -> None:
         """Set mixer parameters."""
         for mixer_number, mixer_data in enumerate(parameters):
             mixer = self._get_mixer(mixer_number)
@@ -334,15 +329,15 @@ class EcoMAX(Device):
         seconds_passed = current_timestamp - self._fuel_burned_timestamp
         fuel_burned = (fuel_consumption / 3600) * seconds_passed
         self._fuel_burned_timestamp = current_timestamp
-        await self.async_set_attribute(DATA_FUEL_BURNED, fuel_burned)
+        await self.async_set_attribute(ATTR_FUEL_BURNED, fuel_burned)
 
-    async def _parse_regulator_data(self, regulator_data: bytes) -> Records:
+    async def _decode_regulator_data(self, regulator_data: bytes) -> DeviceDataType:
         """Add sensor values from the regulator data."""
         offset = 0
         boolean_index = 0
         data = {}
         try:
-            schema = await self.get_value(DATA_SCHEMA)
+            schema = await self.get_value(ATTR_SCHEMA)
             for parameter in schema:
                 parameter_id, parameter_type = parameter
                 if not isinstance(parameter_type, Boolean) and boolean_index > 0:
