@@ -2,18 +2,18 @@
 from __future__ import annotations
 
 import struct
-from typing import Dict, List, Tuple
+from typing import ClassVar, Dict, List, Tuple
 
 from pyplumio import util
 from pyplumio.const import (
-    DATA_MODE,
-    DATA_NETWORK,
-    DATA_PASSWORD,
-    DATA_PRODUCT,
-    DATA_SCHEMA,
-    DATA_VERSION,
+    ATTR_MODE,
+    ATTR_NETWORK,
+    ATTR_PASSWORD,
+    ATTR_PRODUCT,
+    ATTR_SCHEMA,
+    ATTR_VERSION,
 )
-from pyplumio.frames import Response
+from pyplumio.frames import Response, ResponseTypes
 from pyplumio.helpers.data_types import DATA_TYPES, DataType
 from pyplumio.helpers.network_info import (
     EthernetParameters,
@@ -21,8 +21,9 @@ from pyplumio.helpers.network_info import (
     WirelessParameters,
 )
 from pyplumio.helpers.product_info import ProductInfo
+from pyplumio.helpers.typing import DeviceDataType, MessageType
 from pyplumio.helpers.version_info import VersionInfo
-from pyplumio.structures import boiler_parameters, mixer_parameters, uid, var_string
+from pyplumio.structures import boiler_parameters, mixer_parameters, uid
 from pyplumio.structures.outputs import (
     FAN_OUTPUT,
     FEEDER_OUTPUT,
@@ -39,168 +40,8 @@ from pyplumio.structures.temperatures import (
     WATER_HEATER_TEMP,
 )
 
-
-class ProgramVersion(Response):
-    """Represents program version response. Contains software
-    version info.
-    """
-
-    frame_type: int = 0xC0
-
-    def create_message(self) -> bytearray:
-        """Create frame message."""
-        if self._data is None:
-            self._data = {}
-
-        if DATA_VERSION not in self._data:
-            self._data[DATA_VERSION] = VersionInfo()
-
-        version_info = self._data[DATA_VERSION]
-        message = bytearray(15)
-        struct.pack_into(
-            "<2sB2s3s3HB",
-            message,
-            0,
-            version_info.struct_tag,
-            version_info.struct_version,
-            version_info.device_id,
-            version_info.processor_signature,
-            *map(int, version_info.software.split(".", 2)),
-            self.sender,
-        )
-
-        return message
-
-    def parse_message(self, message: bytearray):
-        """Parse frame message."""
-        version_info = VersionInfo()
-        [
-            version_info.struct_tag,
-            version_info.struct_version,
-            version_info.device_id,
-            version_info.processor_signature,
-            software_version1,
-            software_version2,
-            software_version3,
-            self.recipient,
-        ] = struct.unpack_from("<2sB2s3s3HB", message)
-        version_info.software = ".".join(
-            map(str, [software_version1, software_version2, software_version3])
-        )
-        self._data = {DATA_VERSION: version_info}
-
-
-class DeviceAvailable(Response):
-    """Represents device available response. Contains network
-    information and status.
-    """
-
-    frame_type: int = 0xB0
-
-    def create_message(self) -> bytearray:
-        """Creates frame message."""
-        message = bytearray()
-        message += b"\x01"
-        if self._data is None:
-            self._data = {}
-
-        if DATA_NETWORK not in self._data:
-            self._data[DATA_NETWORK] = NetworkInfo()
-
-        network_info = self._data[DATA_NETWORK]
-        message += util.ip4_to_bytes(network_info.eth.ip)
-        message += util.ip4_to_bytes(network_info.eth.netmask)
-        message += util.ip4_to_bytes(network_info.eth.gateway)
-        message.append(network_info.eth.status)
-        message += util.ip4_to_bytes(network_info.wlan.ip)
-        message += util.ip4_to_bytes(network_info.wlan.netmask)
-        message += util.ip4_to_bytes(network_info.wlan.gateway)
-        message.append(network_info.server_status)
-        message.append(network_info.wlan.encryption)
-        message.append(network_info.wlan.signal_quality)
-        message.append(network_info.wlan.status)
-        message += b"\x00" * 4
-        message.append(len(network_info.wlan.ssid))
-        message += network_info.wlan.ssid.encode("utf-8")
-
-        return message
-
-    def parse_message(self, message: bytearray) -> None:
-        """Parse frame message."""
-        offset = 1
-        network_info = NetworkInfo(
-            eth=EthernetParameters(
-                ip=util.ip4_from_bytes(message[offset : offset + 4]),
-                netmask=util.ip4_from_bytes(message[offset + 4 : offset + 8]),
-                gateway=util.ip4_from_bytes(message[offset + 8 : offset + 12]),
-                status=bool(message[offset + 13]),
-            ),
-            wlan=WirelessParameters(
-                ip=util.ip4_from_bytes(message[offset + 13 : offset + 17]),
-                netmask=util.ip4_from_bytes(message[offset + 17 : offset + 21]),
-                gateway=util.ip4_from_bytes(message[offset + 21 : offset + 25]),
-                encryption=int(message[offset + 26]),
-                signal_quality=int(message[offset + 27]),
-                status=bool(message[offset + 28]),
-                ssid=var_string.from_bytes(message, offset + 33)[0],
-            ),
-            server_status=bool(message[offset + 25]),
-        )
-        self._data = {DATA_NETWORK: network_info}
-
-
-class UID(Response):
-    """Represents UID response. Contains product and model info."""
-
-    frame_type: int = 0xB9
-
-    def parse_message(self, message: bytearray) -> None:
-        """Parse frame message."""
-        product_info = ProductInfo()
-        product_info.type, product_info.product = struct.unpack_from("<BH", message)
-        product_info.uid, offset = uid.from_bytes(message, offset=3)
-        product_info.logo, product_info.image = struct.unpack_from("<HH", message)
-        product_info.model, _ = var_string.from_bytes(message, offset + 4)
-        self._data = {DATA_PRODUCT: product_info}
-
-
-class Password(Response):
-    """Represent password response. Contains device service password."""
-
-    frame_type: int = 0xBA
-
-    def parse_message(self, message: bytearray) -> None:
-        """Parse frame message."""
-        password = message[1:].decode() if message[1:] else None
-        self._data = {DATA_PASSWORD: password}
-
-
-class BoilerParameters(Response):
-    """Represents boiler parameters response. Contains editable boiler
-    parameters.
-    """
-
-    frame_type: int = 0xB1
-
-    def parse_message(self, message: bytearray) -> None:
-        """Parse frame message."""
-        self._data, _ = boiler_parameters.from_bytes(message)
-
-
-class MixerParameters(Response):
-    """Represents mixer parameters response. Contains editable mixer
-    parameters.
-    """
-
-    frame_type: int = 0xB2
-
-    def parse_message(self, message: bytearray) -> None:
-        """Parse frame message."""
-        self._data, _ = mixer_parameters.from_bytes(message)
-
-
 REGDATA_SCHEMA: Dict[int, str] = {
-    1792: DATA_MODE,
+    1792: ATTR_MODE,
     1024: HEATING_TEMP,
     1026: FEEDER_TEMP,
     1025: WATER_HEATER_TEMP,
@@ -216,15 +57,160 @@ REGDATA_SCHEMA: Dict[int, str] = {
 }
 
 
+class ProgramVersion(Response):
+    """Represents program version response. Contains software
+    version info.
+    """
+
+    frame_type: ClassVar[int] = ResponseTypes.PROGRAM_VERSION
+
+    def create_message(self, data: DeviceDataType) -> MessageType:
+        """Create frame message."""
+        message = bytearray(15)
+        version_info = data[ATTR_VERSION] if ATTR_VERSION in data else VersionInfo()
+        struct.pack_into(
+            "<2sB2s3s3HB",
+            message,
+            0,
+            version_info.struct_tag,
+            version_info.struct_version,
+            version_info.device_id,
+            version_info.processor_signature,
+            *map(int, version_info.software.split(".", 2)),
+            self.sender,
+        )
+        return message
+
+    def decode_message(self, message: MessageType) -> DeviceDataType:
+        """Decode frame message."""
+        version_info = VersionInfo()
+        [
+            version_info.struct_tag,
+            version_info.struct_version,
+            version_info.device_id,
+            version_info.processor_signature,
+            software_version1,
+            software_version2,
+            software_version3,
+            self.recipient,
+        ] = struct.unpack_from("<2sB2s3s3HB", message)
+        version_info.software = ".".join(
+            map(str, [software_version1, software_version2, software_version3])
+        )
+        return {ATTR_VERSION: version_info}
+
+
+class DeviceAvailable(Response):
+    """Represents device available response. Contains network
+    information and status.
+    """
+
+    frame_type: ClassVar[int] = ResponseTypes.DEVICE_AVAILABLE
+
+    def create_message(self, data: DeviceDataType) -> MessageType:
+        """Creates frame message."""
+        message = bytearray()
+        message += b"\x01"
+        network_info = data[ATTR_NETWORK] if ATTR_NETWORK in data else NetworkInfo()
+        message += util.ip4_to_bytes(network_info.eth.ip)
+        message += util.ip4_to_bytes(network_info.eth.netmask)
+        message += util.ip4_to_bytes(network_info.eth.gateway)
+        message.append(network_info.eth.status)
+        message += util.ip4_to_bytes(network_info.wlan.ip)
+        message += util.ip4_to_bytes(network_info.wlan.netmask)
+        message += util.ip4_to_bytes(network_info.wlan.gateway)
+        message.append(network_info.server_status)
+        message.append(network_info.wlan.encryption)
+        message.append(network_info.wlan.signal_quality)
+        message.append(network_info.wlan.status)
+        message += b"\x00" * 4
+        message.append(len(network_info.wlan.ssid))
+        message += network_info.wlan.ssid.encode("utf-8")
+        return message
+
+    def decode_message(self, message: MessageType) -> DeviceDataType:
+        """Decode frame message."""
+        offset = 1
+        network_info = NetworkInfo(
+            eth=EthernetParameters(
+                ip=util.ip4_from_bytes(message[offset : offset + 4]),
+                netmask=util.ip4_from_bytes(message[offset + 4 : offset + 8]),
+                gateway=util.ip4_from_bytes(message[offset + 8 : offset + 12]),
+                status=bool(message[offset + 13]),
+            ),
+            wlan=WirelessParameters(
+                ip=util.ip4_from_bytes(message[offset + 13 : offset + 17]),
+                netmask=util.ip4_from_bytes(message[offset + 17 : offset + 21]),
+                gateway=util.ip4_from_bytes(message[offset + 21 : offset + 25]),
+                encryption=int(message[offset + 26]),
+                signal_quality=int(message[offset + 27]),
+                status=bool(message[offset + 28]),
+                ssid=util.unpack_string(message, offset + 33),
+            ),
+            server_status=bool(message[offset + 25]),
+        )
+        return {ATTR_NETWORK: network_info}
+
+
+class UID(Response):
+    """Represents UID response. Contains product and model info."""
+
+    frame_type: ClassVar[int] = ResponseTypes.UID
+
+    def decode_message(self, message: MessageType) -> DeviceDataType:
+        """Decode frame message."""
+        product_info = ProductInfo()
+        product_info.type, product_info.product = struct.unpack_from("<BH", message)
+        product_info.uid, offset = uid.from_bytes(message, offset=3)
+        product_info.logo, product_info.image = struct.unpack_from("<HH", message)
+        product_info.model = util.unpack_string(message, offset + 4)
+        return {ATTR_PRODUCT: product_info}
+
+
+class Password(Response):
+    """Represent password response. Contains device service password."""
+
+    frame_type: ClassVar[int] = ResponseTypes.PASSWORD
+
+    def decode_message(self, message: MessageType) -> DeviceDataType:
+        """Decode frame message."""
+        password = message[1:].decode() if message[1:] else None
+        return {ATTR_PASSWORD: password}
+
+
+class BoilerParameters(Response):
+    """Represents boiler parameters response. Contains editable boiler
+    parameters.
+    """
+
+    frame_type: ClassVar[int] = ResponseTypes.BOILER_PARAMETERS
+
+    def decode_message(self, message: MessageType) -> DeviceDataType:
+        """Decode frame message."""
+        return boiler_parameters.from_bytes(message)[0]
+
+
+class MixerParameters(Response):
+    """Represents mixer parameters response. Contains editable mixer
+    parameters.
+    """
+
+    frame_type: ClassVar[int] = ResponseTypes.MIXER_PARAMETERS
+
+    def decode_message(self, message: MessageType) -> DeviceDataType:
+        """Decode frame message."""
+        return mixer_parameters.from_bytes(message)[0]
+
+
 class DataSchema(Response):
     """Represents data schema response. Contains schema that describes
     regdata message structure.
     """
 
-    frame_type: int = 0xD5
+    frame_type: ClassVar[int] = ResponseTypes.DATA_SCHEMA
 
-    def parse_message(self, message: bytearray) -> None:
-        """Parse frame message."""
+    def decode_message(self, message: MessageType) -> DeviceDataType:
+        """Decode frame message."""
         offset = 0
         blocks_number = util.unpack_ushort(message[offset : offset + 2])
         offset += 2
@@ -237,7 +223,7 @@ class DataSchema(Response):
                 schema.append((param_name, DATA_TYPES[param_type]()))
                 offset += 3
 
-        self._data = {DATA_SCHEMA: schema}
+        return {ATTR_SCHEMA: schema}
 
 
 class SetBoilerParameter(Response):
@@ -245,7 +231,7 @@ class SetBoilerParameter(Response):
     that aknowledges, that boiler parameter was successfully changed.
     """
 
-    frame_type: int = 0xB3
+    frame_type: ClassVar[int] = ResponseTypes.SET_BOILER_PARAMETER
 
 
 class SetMixerParameter(Response):
@@ -253,7 +239,7 @@ class SetMixerParameter(Response):
     that aknowledges, that mixer parameter was successfully changed.
     """
 
-    frame_type: int = 0xB4
+    frame_type: ClassVar[int] = ResponseTypes.SET_MIXER_PARAMETER
 
 
 class BoilerControl(Response):
@@ -262,4 +248,4 @@ class BoilerControl(Response):
     processed.
     """
 
-    frame_type: int = 0xBB
+    frame_type: ClassVar[int] = ResponseTypes.BOILER_CONTROL
