@@ -3,9 +3,9 @@ from __future__ import annotations
 
 import asyncio
 import logging
-from typing import Dict, Final, Optional, Tuple
+from typing import Awaitable, Callable, Dict, Final, Optional, Tuple
 
-from pyplumio.const import DATA_NETWORK, ECOMAX_ADDRESS
+from pyplumio.const import ATTR_NETWORK, ECOMAX_ADDRESS
 from pyplumio.devices import Device, get_device_handler
 from pyplumio.exceptions import (
     FrameError,
@@ -13,7 +13,8 @@ from pyplumio.exceptions import (
     UnknownDeviceError,
     UnknownFrameError,
 )
-from pyplumio.frames.requests import CheckDevice, ProgramVersion, StartMaster
+from pyplumio.frames import RequestTypes
+from pyplumio.frames.requests import StartMaster
 from pyplumio.helpers.factory import factory
 from pyplumio.helpers.network_info import (
     EthernetParameters,
@@ -21,7 +22,6 @@ from pyplumio.helpers.network_info import (
     WirelessParameters,
 )
 from pyplumio.helpers.task_manager import TaskManager
-from pyplumio.helpers.typing import AsyncCallback
 from pyplumio.stream import FrameReader, FrameWriter
 
 _LOGGER = logging.getLogger(__name__)
@@ -51,12 +51,12 @@ class Protocol(TaskManager):
     devices: Dict[str, Device]
     _network: NetworkInfo
     _queues: Tuple[asyncio.Queue, asyncio.Queue]
-    _connection_lost_callback: Optional[AsyncCallback]
+    _connection_lost_callback: Optional[Callable[[], Awaitable[None]]]
     _closing: bool = False
 
     def __init__(
         self,
-        connection_lost_callback: Optional[AsyncCallback] = None,
+        connection_lost_callback: Optional[Callable[[], Awaitable[None]]] = None,
         ethernet_parameters: Optional[EthernetParameters] = None,
         wireless_parameters: Optional[WirelessParameters] = None,
     ):
@@ -111,19 +111,20 @@ class Protocol(TaskManager):
             frame = await read_queue.get()
             try:
                 handler, name = _get_device_handler_and_name(frame.sender)
-                device: Device = (
-                    self.devices[name]
-                    if name in self.devices
-                    else factory(handler, queue=write_queue)
-                )
-                device.handle_frame(frame)
-                if frame.is_type(CheckDevice, ProgramVersion):
-                    write_queue.put_nowait(
-                        frame.response(data={DATA_NETWORK: self._network})
-                    )
 
-                self.devices[name] = device
-                self.set_event(name)
+                if name not in self.devices:
+                    device = factory(handler, queue=write_queue)
+                    self.devices[name] = device
+                    self.set_event(name)
+
+                self.devices[name].handle_frame(frame)
+
+                if frame.is_type(
+                    RequestTypes.CHECK_DEVICE, RequestTypes.PROGRAM_VERSION
+                ):
+                    response = frame.response(data={ATTR_NETWORK: self._network})
+                    write_queue.put_nowait(response)
+
             except UnknownDeviceError as e:
                 _LOGGER.debug("UnknownDeviceError: %s", e)
 
@@ -181,7 +182,7 @@ class Protocol(TaskManager):
         if self.writer:
             await self.writer.close()
 
-        for _, device in self.devices.items():
+        for device in self.devices.values():
             await device.shutdown()
 
     async def get_device(self, device: str) -> Device:
