@@ -1,11 +1,11 @@
-"""Contains regulator parameter structure parser."""
+"""Contains regulator parameter structure decoder."""
 from __future__ import annotations
 
 from typing import Dict, Final, List, Optional, Tuple
 
 from pyplumio import util
-from pyplumio.const import DATA_BOILER_PARAMETERS
-from pyplumio.helpers.typing import ParameterTuple, Records
+from pyplumio.const import ATTR_BOILER_PARAMETERS
+from pyplumio.helpers.typing import DeviceDataType, ParameterDataType
 
 PARAMETER_BOILER_CONTROL: Final = "boiler_control"
 BOILER_PARAMETERS: List[str] = [
@@ -152,16 +152,16 @@ BOILER_PARAMETERS: List[str] = [
 
 
 def from_bytes(
-    message: bytearray, offset: int = 0, data: Optional[Records] = None
-) -> Tuple[Records, int]:
-    """Parse bytes and return message data and offset."""
+    message: bytearray, offset: int = 0, data: Optional[DeviceDataType] = None
+) -> Tuple[DeviceDataType, int]:
+    """Decode bytes and return message data and offset."""
     if data is None:
         data = {}
 
     first_parameter = message[offset + 1]
     parameters_number = message[offset + 2]
     offset += 3
-    parameters: Dict[str, ParameterTuple] = {}
+    parameters: Dict[str, ParameterDataType] = {}
     for index in range(first_parameter, parameters_number + first_parameter):
         parameter = util.unpack_parameter(message, offset)
         if parameter is not None:
@@ -170,6 +170,6 @@ def from_bytes(
 
         offset += 3
 
-    data[DATA_BOILER_PARAMETERS] = parameters
+    data[ATTR_BOILER_PARAMETERS] = parameters
 
     return data, offset
