@@ -1,11 +1,11 @@
-"""Contains mixer parameter structure parser."""
+"""Contains mixer parameter structure decoder."""
 from __future__ import annotations
 
 from typing import Dict, List, Optional, Tuple
 
 from pyplumio import util
-from pyplumio.const import DATA_MIXER_PARAMETERS
-from pyplumio.helpers.typing import ParameterTuple, Records
+from pyplumio.const import ATTR_MIXER_PARAMETERS
+from pyplumio.helpers.typing import DeviceDataType, ParameterDataType
 
 MIXER_PARAMETERS: List[str] = [
     "mix_target_temp",
@@ -26,9 +26,9 @@ MIXER_PARAMETERS: List[str] = [
 
 
 def from_bytes(
-    message: bytearray, offset: int = 0, data: Optional[Records] = None
-) -> Tuple[Records, int]:
-    """Parse bytes and return message data and offset."""
+    message: bytearray, offset: int = 0, data: Optional[DeviceDataType] = None
+) -> Tuple[DeviceDataType, int]:
+    """Decode bytes and return message data and offset."""
     if data is None:
         data = {}
 
@@ -37,7 +37,7 @@ def from_bytes(
     offset += 4
     mixer_parameters = []
     for _ in range(mixers_number):
-        parameters: Dict[str, ParameterTuple] = {}
+        parameters: Dict[str, ParameterDataType] = {}
         for parameter_key in range(parameters_number):
             parameter = util.unpack_parameter(message, offset)
             if parameter is not None:
@@ -48,6 +48,6 @@ def from_bytes(
 
         mixer_parameters.append(parameters)
 
-    data[DATA_MIXER_PARAMETERS] = mixer_parameters
+    data[ATTR_MIXER_PARAMETERS] = mixer_parameters
 
     return data, offset
